@@ -1,5 +1,4 @@
 package Text::Xslate::Util;
-# utilities for internals, not for users
 use strict;
 use warnings;
 
@@ -9,13 +8,14 @@ use parent qw(Exporter);
 our @EXPORT_OK = qw(
     mark_raw unmark_raw
     html_escape escaped_string
+    p
+
     literal_to_value value_to_literal
     import_from
     neat
     is_int any_in
     read_around
     make_error
-    p
     $STRING $NUMBER $DEBUG
 );
 
@@ -23,7 +23,7 @@ my $dquoted = qr/" (?: \\. | [^"\\] )* "/xms; # " for poor editors
 my $squoted = qr/' (?: \\. | [^'\\] )* '/xms; # ' for poor editors
 our $STRING  = qr/(?: $dquoted | $squoted )/xms;
 
-our $NUMBER  = qr/ [+-]? (?:
+our $NUMBER  = qr/ (?:
         (?: [0-9][0-9_]* (?: \. [0-9_]+)? \b) # decimal
         |
         (?: 0 (?:
@@ -294,6 +294,8 @@ This is the entity of the C<html_escape> filter.
 
 =head3 C<p($any)>
 
+Displays the contents of I<$any> using C<Data::Dumper>.
+
 This is the entity of the C<dump> filter, useful for debugging.
 
 =head1 SEE ALSO
